<TS version="2.1" language="vi">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Nhấn chuột phải để sửa địa chỉ hoặc nhãn</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Tạo địa chỉ mới</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Mới</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">Sao chép địa chỉ được chọn vào bộ nhớ tạm</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Sao chép</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">Đ&amp;óng</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Xoá địa chỉ được chọn khỏi danh sách</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Nhập địa chỉ hoặc nhãn để tìm kiếm</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Xuất dữ liệu ở thẻ hiện tại ra tập tin.</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Xuất</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Xoá</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Chọn địa chỉ để gửi coin đến</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Các địa chỉ này là các địa chỉ Bitcoin dùng để thanh toán.Luôn luôn kiểm tra số dư và địa chỉ nhận trước khi gởi chuyển tiền ảo. </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Sao chép địa chỉ</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Sao chép &amp;Nhãn</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Chỉnh sửa</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Xuất danh sách địa chỉ</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Địa chỉ gửi%1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Quá trình xuất dữ liệu đã thất bại</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nhãn</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Địa chỉ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(không có nhãn)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Hộp thoại cụm mật khẩu</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Nhập mật khẩu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Mật khẩu mới</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Nhập lại mật khẩu</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Hiện mật khẩu</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Mã hoá ví</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Hoạt động này cần mật khẩu ví của bạn để mở khoá ví.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Mở khoá ví</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Đổi mật khẩu</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Xác nhận mã hóa ví</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Cảnh báo: Nếu bạn mã hóa ví và mất cụm mật khẩu, bạn sẽ &lt;b&gt;MẤT TẤT CẢ CÁC BITCOIN&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Bạn có chắc chắn muốn mã hoá ví không?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Đã mã hoá ví</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Nhập cụm mật khẩu mới cho ví.&lt;br/&gt;Vui lòng sử dụng cụm mật khẩu gồm &lt;b&gt;mười ký tự ngẫu nhiên trở lên&lt;/b&gt;, hoặc &lt;b&gt;tám từ trở lên&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Nhập mật khẩu cũ và mật khẩu mới cho ví.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Xin lưu ý rằng mã hoá ví của bạn không thể bảo về hoàn toàn Bitcoin của bạn khỏi việc bị đánh cắp mới các phần mềm gián điệp nhiễm vào máy tính của bạn.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Ví sẽ được mã hoá</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Ví của bạn sẽ được mã hoá.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Ví của bạn đã được mã hoá.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Mã hoá ví thất bại</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Mã hoá ví thất bại do lỗi nội bộ. Ví của bạn vẫn chưa được mã hoá.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Mật khẩu đã nhập không đúng.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Mở khóa ví thất bại</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Cụm mật khẩu đã nhập để giải mã ví không đúng.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Cụm mật khẩu đã nhập để giải mã ví không đúng. Nó chứa ký tự rỗng (có dung lượng 0 byte). Nếu nó đã được thiết đặt từ một phiên bản cũ hơn phiên bản 25.0 của phần mềm này, vui lòng thử lại với các ký tự đứng trước ký tự rỗng đầu tiên (không bao gồm chính nó). Nếu cách này thành công, vui lòng thiết đặt cụm mật khẩu mới để tránh xảy ra sự cố tương tự trong tương lai.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Cụm mật khẩu thay đổi thành công.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Thay đổi cụm mật khẩu thất bại.</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Cụm mật khẩu cũ đã nhập để giải mã ví không đúng. Nó chứa ký tự rỗng (có dung lượng 0 byte). Nếu nó đã được thiết đặt từ một phiên bản cũ hơn phiên bản 25.0 của phần mềm này, vui lòng thử lại với các ký tự đứng trước ký tự rỗng đầu tiên (không bao gồm chính nó).</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Cảnh báo: Phím Caps Lock đang được kích hoạt!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Bị cấm cho đến</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Tệp cài đặt %1 có thể bị hư hại hoặc không hợp lệ.</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Lỗi nghiêm trong. %1 không thể tiếp tục và sẽ thoát ra</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Đã xảy ra lỗi nội bộ. %1 sẽ cố gắng tiếp tục một cách an toàn. Đây là một lỗi không mong muốn có thể được báo cáo như mô tả bên dưới.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Bạn muốn đặt lại cài đặt về giá trị mặc định hay hủy bỏ mà không thực hiện thay đổi?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Đã xảy ra lỗi nghiêm trọng. Kiểm tra xem tệp cài đặt có thể ghi được không hoặc thử chạy với -nosettings.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Lỗi: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 vẫn chưa thoát ra một cách an toàn…</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%ngiây</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%nphút</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%ngiờ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%nngày</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%ntuần</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%nnăm</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Tổng quan</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Hiển thị tổng quan ví</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Các Giao Dịch</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Trình duyệt lịch sử giao dịch</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">T&amp;hoát</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Đóng ứng dụng</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Khoảng %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Hiện thông tin khoảng %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Về &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Hiện thông tin về Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Sửa đổi tùy chỉnh cấu hình cho %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Tạo một ví mới</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Thu nhỏ</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Ví tiền</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Hoạt động mạng được vô hiệu.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proxy là &lt;b&gt; cho phép &lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Gửi coin đến một địa chỉ Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Backup ví đến một địa chỉ khác</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Thay đổi cụm mật khẩu cho ví đã mã hóa</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Gửi</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Nhận</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Mã hóa ví…</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Mã hóa private key thuộc về ví của bạn</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Thay dổi Passphrase…</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Đăng ký lời nhắn với địa chỉ Bitcoin của bạn để chứng minh quyền sở hữu chúng</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Xác minh tin nhắn…</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Xác minh lời nhắn để chắc chắn đã được đăng ký với địa chỉ Bitcoin xác định</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Đóng ví…</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Tạo ví…</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Đóng tất cả các ví…</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Tệp</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Cài đặt</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Giúp đỡ</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Các thanh công cụ</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Đồng bộ hóa tiêu đề (%1%)...</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Đồng bộ hóa với network...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Lập chỉ mục các khối trên đĩa…</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Xử lý khối trên đĩa…</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Đã xử lý %n khối của lịch sử giao dịch.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 phía sau</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Lỗi</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Thông tin</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">cập nhật</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Tải một phần giao dịch Bitcoin đã ký</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">Tải PSBT từ &amp;khay nhớ tạm…</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Tải một phần giao dịch Bitcoin đã ký từ khay nhớ tạm</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Cửa sổ node</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Mở dòng lệnh tìm và gỡ lỗi cho node</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">Các địa chỉ đang &amp;gửi</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">Các địa chỉ đang &amp;nhận</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Mở một bitcoin: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Mớ ví</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Mở một ví</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Đông ví</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Khôi phục ví...</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Khôi phục ví từ tệp đã sao lưu</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Đóng tất cả ví</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Hiển thị %1 tin nhắn hỗ trợ để nhận được danh sách Bitcoin command-line khả dụng</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Giá trị mặt nạ</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">Che các giá trị trong tab Tổng quan</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">ví mặc định</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Không có ví nào</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">Tải bản sao lưu ví</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Khôi phục ví</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished">Nhấn Ctrl + M</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Ẩn</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">Trìn&amp;h diễn</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%nkết nối đang hoạt động với mạng lưới Bitcoin</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Nhấp để có thêm hành động.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Hiển thị tab ngang hàng</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Tắt hoạt động mạng</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Bật hoạt động mạng</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">Tiền đồng bộ hóa Headers (%1%)…</translation>
    </message>
    <message>
        <source>Error creating wallet</source>
        <translation type="unfinished">Lỗi tạo ví</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Lỗi: %1</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Khóa riêng tư &lt;b&gt;đã tắt&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Ví thì &lt;b&gt;được mã hóa &lt;/b&gt; và hiện tại &lt;b&gt;đã khóa&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Ví thì &lt;b&gt;được mã hóa &lt;/b&gt; và hiện tại &lt;b&gt;đã khóa&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">Đơn vị để hiển thị số tiền. Nhấp để chọn đơn vị khác.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Chế độ Tree</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Chế độ List</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">Sao chép giao dịch &amp;ID và chỉ mục đầu ra</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(không có nhãn)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Too many external signers found</source>
        <translation type="unfinished">Có quá nhiều người ký từ bên ngoài được tìm thấy</translation>
    </message>
</context>
<context>
    <name>LoadWalletsActivity</name>
    <message>
        <source>Load Wallets</source>
        <extracomment>Title of progress window which is displayed when wallets are being loaded.</extracomment>
        <translation type="unfinished">Tải ví</translation>
    </message>
    <message>
        <source>Loading wallets…</source>
        <extracomment>Descriptive text of the load wallets progress window which indicates to the user that wallets are currently being loaded.</extracomment>
        <translation type="unfinished">Đang tải ví…</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">ví mặc định</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Mớ ví</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Khôi phục ví</translation>
    </message>
    <message>
        <source>Restoring Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the restore wallets progress window which indicates to the user that wallets are currently being restored.</extracomment>
        <translation type="unfinished">Đang khôi phục ví &lt;b&gt;%1&lt;/b&gt;…</translation>
    </message>
    <message>
        <source>Restore wallet failed</source>
        <extracomment>Title of message box which is displayed when the wallet could not be restored.</extracomment>
        <translation type="unfinished">Khôi phục ví thất bại</translation>
    </message>
    <message>
        <source>Restore wallet warning</source>
        <extracomment>Title of message box which is displayed when the wallet is restored with some warning.</extracomment>
        <translation type="unfinished">Cảnh báo khối phục ví</translation>
    </message>
    <message>
        <source>Restore wallet message</source>
        <extracomment>Title of message box which is displayed when the wallet is successfully restored.</extracomment>
        <translation type="unfinished">Tin nhắn khôi phục ví</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Đông ví</translation>
    </message>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">Bạn có chắc chắn muốn đóng ví không &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Đóng tất cả ví</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Sử dụng thiết bị ký bên ngoài chẳng hạn như ví phần cứng. Trước tiên, hãy định cấu hình tập lệnh người ký bên ngoài trong tùy chọn ví.</translation>
    </message>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Người ký tên bên ngoài</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Được biên dịch mà không có hỗ trợ ký bên ngoài (bắt buộc đối với ký bên ngoài)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Sửa địa chỉ</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Chỉnh sửa địa chỉ nhận</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Chỉnh sửa địa chỉ gửi</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB dung lượng khả dụng</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB cần thiết)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB cần cho toàn blockchain)</numerusform>
        </translation>
    </message>
    <message>
        <source>Choose data directory</source>
        <translation type="unfinished">Chọn đường dẫn dữ liệu</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(đủ để khôi phục các bản sao lưu trong %n ngày)</numerusform>
        </translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation type="unfinished">Lỗi: Danh mục data xác định "%1" không thể được tạo.</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Chào mừng</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">Chào mừng bạn đến %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation type="unfinished">Đây là lần đầu chương trình khởi chạy, bạn có thể chọn nơi %1 sẽ lưu trữ dữ liệu.</translation>
    </message>
    <message>
        <source>Limit block chain storage to</source>
        <translation type="unfinished">Giới hạn lưu trữ chuỗi khối thành</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation type="unfinished">Đảo ngược lại thiết lập này yêu cầu tại lại toàn bộ chuỗi khối. Tải về toàn bộ chuỗi khối trước và loại nó sau đó sẽ nhanh hơn. Vô hiệu hóa một số tính năng nâng cao.</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2 GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation type="unfinished">Khi bạn nhấn OK, %1 sẽ bắt đầu tải xuống và xử lý toàn bộ chuỗi chính %4 (%2 GB), bắt đầu từ các giao dịch sớm nhất trong %3 khi %4 được khởi chạy ban đầu.</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished">Về %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Tùy chọn dòng lệnh</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>%1 is shutting down…</source>
        <translation type="unfinished">%1 đang tắt…</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Unknown…</source>
        <translation type="unfinished">Không xác định…</translation>
    </message>
    <message>
        <source>calculating…</source>
        <translation type="unfinished">đang tính toán…</translation>
    </message>
    <message>
        <source>Unknown. Syncing Headers (%1, %2%)…</source>
        <translation type="unfinished">Không xác định. Đồng bộ hóa tiêu đề (%1, %2%)…</translation>
    </message>
    <message>
        <source>Unknown. Pre-syncing Headers (%1, %2%)…</source>
        <translation type="unfinished">Không xác định. Tiền đồng bộ hóa Headers (%1, %2%)...</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Dán địa chỉ từ khay nhớ tạm</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation type="unfinished">Tự động bắt đầu %1 sau khi đăng nhập vào hệ thống.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation type="unfinished">&amp;Bắt đầu %1 trên đăng nhập hệ thống</translation>
    </message>
    <message>
        <source>Enabling pruning significantly reduces the disk space required to store transactions. All blocks are still fully validated. Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">Cho phép cắt bớt làm giảm đáng kể không gian đĩa cần thiết để lưu trữ các giao dịch. Tất cả các khối vẫn được xác nhận đầy đủ. Hoàn nguyên cài đặt này yêu cầu tải xuống lại toàn bộ chuỗi khối.</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation type="unfinished">Kích thước bộ nhớ cache của &amp;cơ sở dữ liệu</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation type="unfinished">Số lượng tập lệnh và chuỗi &amp;xác minh</translation>
    </message>
    <message>
        <source>Full path to a %1 compatible script (e.g. C:\Downloads\hwi.exe or /Users/you/Downloads/hwi.py). Beware: malware can steal your coins!</source>
        <translation type="unfinished">Đường dẫn đầy đủ tới một tệp mã tương thích với %1 (ví dụ: C:\Downloads\hwi.exe hoặc /Users/you/Downloads/hwi.py). Cẩn trọng: các phần mềm độc hại có thể đánh cắp tiền của bạn!</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">Địa chỉ IP của proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Options set in this dialog are overridden by the command line:</source>
        <translation type="unfinished">Các tùy chọn trong hộp thoại này bị ghi đè bởi dòng lệnh</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Đặt lại tất cả các tùy chọn máy khách về mặc định.</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Mạng</translation>
    </message>
    <message>
        <source>Maximum database cache size. A larger cache can contribute to faster sync, after which the benefit is less pronounced for most use cases. Lowering the cache size will reduce memory usage. Unused mempool memory is shared for this cache.</source>
        <extracomment>Tooltip text for Options window setting that sets the size of the database cache. Explains the corresponding effects of increasing/decreasing this value.</extracomment>
        <translation type="unfinished">Kích thước bộ đệm cơ sở dữ liệu tối đa. Bộ nhớ đệm lớn hơn có thể góp phần đồng bộ hóa nhanh hơn, sau đó lợi ích ít rõ rệt hơn đối với hầu hết các trường hợp sử dụng. Giảm kích thước bộ nhớ cache sẽ làm giảm mức sử dụng bộ nhớ. Bộ nhớ mempool không sử dụng được chia sẻ cho bộ nhớ cache này.</translation>
    </message>
    <message>
        <source>Set the number of script verification threads. Negative values correspond to the number of cores you want to leave free to the system.</source>
        <extracomment>Tooltip text for Options window setting that sets the number of script verification threads. Explains that negative values mean to leave these many cores free to the system.</extracomment>
        <translation type="unfinished">Đặt số lượng chuỗi xác minh tập lệnh. Giá trị âm tương ứng với số lõi bạn muốn để lại miễn phí cho hệ thống.</translation>
    </message>
    <message>
        <source>This allows you or a third party tool to communicate with the node through command-line and JSON-RPC commands.</source>
        <extracomment>Tooltip text for Options window setting that enables the RPC server.</extracomment>
        <translation type="unfinished">Điều này cho phép bạn hoặc công cụ của bên thứ ba giao tiếp với nút thông qua các lệnh dòng lệnh và JSON-RPC.</translation>
    </message>
    <message>
        <source>Enable R&amp;PC server</source>
        <extracomment>An Options window setting to enable the RPC server.</extracomment>
        <translation type="unfinished">Bật máy chủ R&amp;PC</translation>
    </message>
    <message>
        <source>Whether to set subtract fee from amount as default or not.</source>
        <extracomment>Tooltip text for Options window setting that sets subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">Có đặt trừ phí khỏi số tiền làm mặc định hay không.</translation>
    </message>
    <message>
        <source>Subtract &amp;fee from amount by default</source>
        <extracomment>An Options window setting to set subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">Trừ &amp;phí khỏi số tiền theo mặc định</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Chuyên gia</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation type="unfinished">Bật tính năng &amp;kiểm soát và tiền xu</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation type="unfinished">Nếu bạn vô hiệu hóa chi tiêu của thay đổi chưa được xác nhận, thay đổi từ một giao dịch sẽ không thể được sử dụng cho đến khi giao dịch đó có ít nhất một xác nhận. Điều này cũng ảnh hưởng đến cách tính số dư của bạn.</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation type="unfinished">&amp;Chi tiêu thay đổi chưa được xác nhận</translation>
    </message>
    <message>
        <source>Enable &amp;PSBT controls</source>
        <extracomment>An options window setting to enable PSBT controls.</extracomment>
        <translation type="unfinished">Bật điều khiển &amp;PSBT</translation>
    </message>
    <message>
        <source>Whether to show PSBT controls.</source>
        <extracomment>Tooltip text for options window setting that enables PSBT controls.</extracomment>
        <translation type="unfinished">Có hiển thị các điều khiển PSBT hay không.</translation>
    </message>
    <message>
        <source>Third-party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation type="unfinished">URL của bên thứ ba (ví dụ: trình khám phá khối) xuất hiện trong tab giao dịch dưới dạng các mục menu ngữ cảnh. %s trong URL được thay thế bằng mã băm giao dịch. Nhiều URL được phân tách bằng thanh dọc |. </translation>
    </message>
    <message>
        <source>&amp;Third-party transaction URLs</source>
        <translation type="unfinished">&amp;URL giao dịch của bên thứ ba</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Được biên dịch mà không có hỗ trợ ký bên ngoài (bắt buộc đối với ký bên ngoài)</translation>
    </message>
    <message>
        <source>Current settings will be backed up at "%1".</source>
        <extracomment>Text explaining to the user that the client's current settings will be backed up at a specific location. %1 is a stand-in argument for the backup location's path.</extracomment>
        <translation type="unfinished">Các thiết lập hiện tại sẽ được sao lưu tại"%1".</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Tiếp tục</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Lỗi</translation>
    </message>
    </context>
<context>
    <name>OptionsModel</name>
    <message>
        <source>Could not read setting "%1", %2.</source>
        <translation type="unfinished">Không thể đọc thiết lập "%1", %2.</translation>
    </message>
</context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>PSBT Operations</source>
        <translation type="unfinished">Các thao tác PSBT</translation>
    </message>
    <message>
        <source>Cannot sign inputs while wallet is locked.</source>
        <translation type="unfinished">Không thể ký đầu vào khi ví bị khóa.</translation>
    </message>
    <message>
        <source>Transaction has %1 unsigned inputs.</source>
        <translation type="unfinished">Giao dịch có %1 đầu vào chưa được ký.</translation>
    </message>
    <message>
        <source>Transaction still needs signature(s).</source>
        <translation type="unfinished">Giao dịch vẫn cần (các) chữ ký.</translation>
    </message>
    <message>
        <source>(But no wallet is loaded.)</source>
        <translation type="unfinished">(Nhưng không có ví nào được tải.)</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">Tuổi</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Địa chỉ</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Whether we relay transactions to this peer.</source>
        <translation type="unfinished">Có nên chuyển tiếp giao dịch đến đồng đẳng này.</translation>
    </message>
    <message>
        <source>Transaction Relay</source>
        <translation type="unfinished">Chuyển tiếp giao dịch</translation>
    </message>
    <message>
        <source>Last Transaction</source>
        <translation type="unfinished">Giao dịch cuối cùng</translation>
    </message>
    <message>
        <source>Whether we relay addresses to this peer.</source>
        <extracomment>Tooltip text for the Address Relay field in the peer details area, which displays whether we relay addresses to this peer (Yes/No).</extracomment>
        <translation type="unfinished">Cho dù chúng tôi chuyển tiếp địa chỉ đến đồng đẳng này.</translation>
    </message>
    <message>
        <source>Address Relay</source>
        <extracomment>Text title for the Address Relay field in the peer details area, which displays whether we relay addresses to this peer (Yes/No).</extracomment>
        <translation type="unfinished">Chuyển tiếp địa chỉ</translation>
    </message>
    <message>
        <source>The total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</source>
        <extracomment>Tooltip text for the Addresses Processed field in the peer details area, which displays the total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</extracomment>
        <translation type="unfinished">Tổng số các địa chỉ đã được xử lý thành công nhận được từ người này (ngoại trừ các địa chỉ sụt giảm do giới hạn tốc độ) </translation>
    </message>
    <message>
        <source>The total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</source>
        <extracomment>Tooltip text for the Addresses Rate-Limited field in the peer details area, which displays the total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</extracomment>
        <translation type="unfinished">Tổng số các địa chỉ nhận được từ người ngày đã bị sụt giảm (không được xử lý thành công) do giới hạn về tốc độ.</translation>
    </message>
    <message>
        <source>Addresses Processed</source>
        <extracomment>Text title for the Addresses Processed field in the peer details area, which displays the total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</extracomment>
        <translation type="unfinished">Các địa chỉ đã được xử lý</translation>
    </message>
    <message>
        <source>Addresses Rate-Limited</source>
        <extracomment>Text title for the Addresses Rate-Limited field in the peer details area, which displays the total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</extracomment>
        <translation type="unfinished">Tỷ lệ địa chỉ có giới hạn</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Cửa sổ node</translation>
    </message>
    <message>
        <source>&amp;Copy IP/Netmask</source>
        <extracomment>Context menu action to copy the IP/Netmask of a banned peer. IP/Netmask is the combination of a peer's IP address and its Netmask. For IP address, see: https://en.wikipedia.org/wiki/IP_address.</extracomment>
        <translation type="unfinished">&amp;Sao chép IP/Netmask</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Base58 (Legacy)</source>
        <translation type="unfinished">Base58 (Di sản)</translation>
    </message>
    <message>
        <source>Not recommended due to higher fees and less protection against typos.</source>
        <translation type="unfinished">Không được khuyến khích vì tốn nhiều phí hơn và ít được bảo vệ trước lỗi chính tả hơn.</translation>
    </message>
    <message>
        <source>Generates an address compatible with older wallets.</source>
        <translation type="unfinished">Tạo một địa chỉ tương thích với các ví cũ hơn.</translation>
    </message>
    <message>
        <source>Generates a native segwit address (BIP-173). Some old wallets don't support it.</source>
        <translation type="unfinished">Tạo một địa chỉ segwit chuyên biệt (BIP-173). Một số ví cũ sẽ không hỗ trợ.</translation>
    </message>
    <message>
        <source>Bech32m (BIP-350) is an upgrade to Bech32, wallet support is still limited.</source>
        <translation type="unfinished">Bech32m (BIP-350) là bản nâng cấp của Bech32, hỗ trợ ví vẫn còn hạn chế.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Ví tiền</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nhãn</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(không có nhãn)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Using the fallbackfee can result in sending a transaction that will take several hours or days (or never) to confirm. Consider choosing your fee manually or wait until you have validated the complete chain.</source>
        <translation type="unfinished">Sử dụng fallbackfee có thể dẫn đến việc gửi giao dịch mất vài giờ hoặc vài ngày (hoặc không bao giờ) để xác nhận. Hãy cân nhắc khi tự chọn phí của bạn hoặc đợi cho tới khi bạn xác minh xong chuỗi hoàn chỉnh.</translation>
    </message>
    <message>
        <source>Do you want to create this transaction?</source>
        <extracomment>Message displayed when attempting to create a transaction. Cautionary text to prompt the user to verify that the displayed transaction details represent the transaction the user intends to create.</extracomment>
        <translation type="unfinished">Bạn có muốn tạo giao dịch này không?</translation>
    </message>
    <message>
        <source>Please, review your transaction. You can create and send this transaction or create a Partially Signed Bitcoin Transaction (PSBT), which you can save or copy and then sign with, e.g., an offline %1 wallet, or a PSBT-compatible hardware wallet.</source>
        <extracomment>Text to inform a user attempting to create a transaction of their current options. At this stage, a user can send their transaction or create a PSBT. This string is displayed when both private keys and PSBT controls are enabled.</extracomment>
        <translation type="unfinished">Vui lòng xem lại giao dịch của bạn. Bạn có thể tạo và gửi giao dịch này hoặc tạo Giao dịch Bitcoin được ký một phần (PSBT), bạn có thể lưu hoặc sao chép và sau đó ký bằng, ví dụ: ví %1 ngoại tuyến hoặc ví phần cứng tương thích với PSBT.</translation>
    </message>
    <message>
        <source>Unsigned Transaction</source>
        <comment>PSBT copied</comment>
        <extracomment>Caption of "PSBT has been copied" messagebox</extracomment>
        <translation type="unfinished">Giao dịch chưa được ký</translation>
    </message>
    <message>
        <source>The PSBT has been copied to the clipboard. You can also save it.</source>
        <translation type="unfinished">PSBT đã được sao chép vào bảng tạm. Bạn cũng có thế lưu nó lại.</translation>
    </message>
    <message>
        <source>PSBT saved to disk</source>
        <translation type="unfinished">PSBT đã được lưu vào ổ đĩa.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Ước tính sẽ bắt đầu xác nhận trong %n khối.</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(không có nhãn)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Dán địa chỉ từ khay nhớ tạm</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    <message>
        <source>Send</source>
        <translation type="unfinished">Gửi</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Dán địa chỉ từ khay nhớ tạm</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>press q to shutdown</source>
        <translation type="unfinished">nhấn q để tắt máy</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>0/unconfirmed, in memory pool</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an unconfirmed transaction that is in the memory pool.</extracomment>
        <translation type="unfinished">0/xác nhận, ở trong bể bộ nhớ - memory pool</translation>
    </message>
    <message>
        <source>0/unconfirmed, not in memory pool</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an unconfirmed transaction that is not in the memory pool.</extracomment>
        <translation type="unfinished">0/xác nhận, không ở trong bể bộ nhớ - memory pool</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>sẽ trưởng thành sau%n khối nữa </numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nhãn</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(không có nhãn)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Other</source>
        <translation type="unfinished">Khác</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <extracomment>Transactions table context menu action to show the selected transaction in a third-party block explorer. %1 is a stand-in argument for the URL of the explorer.</extracomment>
        <translation type="unfinished">Hiển thị trong %1</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nhãn</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Địa chỉ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Quá trình xuất dữ liệu đã thất bại</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Tạo một ví mới</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Lỗi</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Copied to clipboard</source>
        <comment>Fee-bump PSBT saved</comment>
        <translation type="unfinished">Đã sao chép vào bảng tạm.</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">ví mặc định</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Xuất</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Xuất dữ liệu ở thẻ hiện tại ra tập tin.</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error reading %s! Transaction data may be missing or incorrect. Rescanning wallet.</source>
        <translation type="unfinished">Lỗi khi đọc%s! Dữ liệu giao dịch có thể bị thiếu hoặc không chính xác. Đang quét lại ví.</translation>
    </message>
    <message>
        <source>Invalid or corrupt peers.dat (%s). If you believe this is a bug, please report it to %s. As a workaround, you can move the file (%s) out of the way (rename, move, or delete) to have a new one created on the next start.</source>
        <translation type="unfinished">peers.dat (%s) không hợp lệ hoặc bị hỏng. Nếu bạn cho rằng đây là lỗi, vui lòng báo cáo cho %s. Để giải quyết vấn đề này, bạn có thể di chuyển tệp (%s) ra khỏi (đổi tên, di chuyển hoặc xóa) để tạo tệp mới vào lần bắt đầu tiếp theo.</translation>
    </message>
    <message>
        <source>Prune mode is incompatible with -reindex-chainstate. Use full -reindex instead.</source>
        <translation type="unfinished">Chế độ rút gọn không tương thích với -reindex-chainstate. Sử dụng -reindex ở chế độ đầy đủ.</translation>
    </message>
    <message>
        <source>Unsupported chainstate database format found. Please restart with -reindex-chainstate. This will rebuild the chainstate database.</source>
        <translation type="unfinished">Tìm thấy định dạng cơ sở dữ liệu trạng thái chuỗi không được hỗ trợ. Vui lòng khỏi động lại với -reindex-chainstate. Việc này sẽ tái thiết lập cơ sở dữ liệu trạng thái chuỗi.</translation>
    </message>
    <message>
        <source>Wallet created successfully. The legacy wallet type is being deprecated and support for creating and opening legacy wallets will be removed in the future.</source>
        <translation type="unfinished">Ví đã được tạo thành công. Loại ví Legacy đang bị phản đối và việc hỗ trợ mở các ví Legacy mới sẽ bị loại bỏ trong tương lai</translation>
    </message>
    <message>
        <source>Cannot set -forcednsseed to true when setting -dnsseed to false.</source>
        <translation type="unfinished">Không thể đặt -forcednsseed thành true khi đặt -dnsseed thành false.</translation>
    </message>
    <message>
        <source>Cannot provide specific connections and have addrman find outgoing connections at the same time.</source>
        <translation type="unfinished">Không thể cung cấp các kết nối cụ thể và yêu cầu addrman tìm các kết nối gửi đi cùng một lúc.</translation>
    </message>
    <message>
        <source>Error loading %s: External signer wallet being loaded without external signer support compiled</source>
        <translation type="unfinished">Lỗi khi tải %s: Ví người ký bên ngoài đang được tải mà không có hỗ trợ người ký bên ngoài được biên dịch</translation>
    </message>
    <message>
        <source>Failed to rename invalid peers.dat file. Please move or delete it and try again.</source>
        <translation type="unfinished">Không thể đổi tên tệp ngang hàng không hợp lệ. Vui lòng di chuyển hoặc xóa nó và thử lại.</translation>
    </message>
    <message>
        <source>Unexpected legacy entry in descriptor wallet found. Loading wallet %s

The wallet might have been tampered with or created with malicious intent.
</source>
        <translation type="unfinished">Phát hiện mục thừa kế bất thường trong ví mô tả. Đang tải ví %s

Ví này có thể đã bị can thiệp hoặc tạo ra với ý đồ bất chính.
</translation>
    </message>
    <message>
        <source>Unrecognized descriptor found. Loading wallet %s

The wallet might had been created on a newer version.
Please try running the latest software version.
</source>
        <translation type="unfinished">Phát hiện mô tả không xác định. Đang tải ví %s

Ví này có thể đã được tạo bởi một phiên bản mới hơn.
Vui lòng thử chạy phiên bản phần mềm mới nhất.
</translation>
    </message>
    <message>
        <source>
Unable to cleanup failed migration</source>
        <translation type="unfinished">
Không thể dọn dẹp quá trình chuyển đã thất bại</translation>
    </message>
    <message>
        <source>
Unable to restore backup of wallet.</source>
        <translation type="unfinished">
Không thể khôi phục bản sao lưu của ví.</translation>
    </message>
    <message>
        <source>Block verification was interrupted</source>
        <translation type="unfinished">Việc xác minh khối đã bị gián đoạn</translation>
    </message>
    <message>
        <source>Error reading configuration file: %s</source>
        <translation type="unfinished">Lỗi khi đọc tệp cài đặt cấu hình: %s</translation>
    </message>
    <message>
        <source>Error: Cannot extract destination from the generated scriptpubkey</source>
        <translation type="unfinished">Lỗi: Không thể trích xuất điểm đến trong mã khóa công khai đã tạo</translation>
    </message>
    <message>
        <source>Error: Failed to create new watchonly wallet</source>
        <translation type="unfinished">Lỗi: Tạo ví chỉ xem mới thất bại</translation>
    </message>
    <message>
        <source>Error: This wallet already uses SQLite</source>
        <translation type="unfinished">Lỗi: Ví này đã dùng SQLite</translation>
    </message>
    <message>
        <source>Error: This wallet is already a descriptor wallet</source>
        <translation type="unfinished">Lỗi: Ví này đã là một ví mô tả</translation>
    </message>
    <message>
        <source>Error: Unable to begin reading all records in the database</source>
        <translation type="unfinished">Lỗi: Không thể bắt đầu việc đọc tất cả bản ghi trong cơ sở dữ liệu</translation>
    </message>
    <message>
        <source>Error: Unable to make a backup of your wallet</source>
        <translation type="unfinished">Lỗi: Không thể tạo bản sao lưu cho ví của bạn</translation>
    </message>
    <message>
        <source>Error: Unable to read all records in the database</source>
        <translation type="unfinished">Lỗi: Không thể đọc tất cả bản ghi trong cơ sở dữ liệu</translation>
    </message>
    <message>
        <source>Error: Unable to remove watchonly address book data</source>
        <translation type="unfinished">Lỗi: Không thể xóa dữ liệu của sổ địa chỉ chỉ xem</translation>
    </message>
    <message>
        <source>Input not found or already spent</source>
        <translation type="unfinished">Đầu vào không được tìm thấy hoặc đã được sử dụng</translation>
    </message>
    <message>
        <source>Insufficient dbcache for block verification</source>
        <translation type="unfinished">Không đủ bộ đệm (dbcache) để xác minh khối</translation>
    </message>
    <message>
        <source>Invalid amount for %s=&lt;amount&gt;: '%s' (must be at least %s)</source>
        <translation type="unfinished">Số lượng không hợp lệ cho %s=&lt;amount&gt;: '%s' (tối thiểu phải là %s)</translation>
    </message>
    <message>
        <source>Invalid amount for %s=&lt;amount&gt;: '%s'</source>
        <translation type="unfinished">Số lượng không hợp lệ cho %s=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid port specified in %s: '%s'</source>
        <translation type="unfinished">Cổng được chỉ định không hợp lệ trong %s: '%s'</translation>
    </message>
    <message>
        <source>Invalid pre-selected input %s</source>
        <translation type="unfinished">Đầu vào được chọn trước không hợp lệ %s</translation>
    </message>
    <message>
        <source>Listening for incoming connections failed (listen returned error %s)</source>
        <translation type="unfinished">Lắng nghe những kết nối thất bại sắp xảy ra (lắng nghe lỗi được trả về %s)</translation>
    </message>
    <message>
        <source>Missing amount</source>
        <translation type="unfinished">Số tiền còn thiếu</translation>
    </message>
    <message>
        <source>Missing solving data for estimating transaction size</source>
        <translation type="unfinished">Thiếu dữ liệu giải quyết để ước tính quy mô giao dịch</translation>
    </message>
    <message>
        <source>No addresses available</source>
        <translation type="unfinished">Không có địa chỉ</translation>
    </message>
    <message>
        <source>Not found pre-selected input %s</source>
        <translation type="unfinished">Đầu vào được chọn trước không tìm thấy %s</translation>
    </message>
    <message>
        <source>Not solvable pre-selected input %s</source>
        <translation type="unfinished">Đầu vào được chọn trước không giải được %s</translation>
    </message>
    <message>
        <source>Specified data directory "%s" does not exist.</source>
        <translation type="unfinished">Đường dẫn dữ liệu được chỉ định "%s" không tồn tại.</translation>
    </message>
    <message>
        <source>Transaction change output index out of range</source>
        <translation type="unfinished">Chỉ số đầu ra thay đổi giao dịch nằm ngoài phạm vi</translation>
    </message>
    <message>
        <source>Transaction needs a change address, but we can't generate it.</source>
        <translation type="unfinished">Giao dịch cần thay đổi địa chỉ, nhưng chúng tôi không thể tạo địa chỉ đó.</translation>
    </message>
    <message>
        <source>Unable to allocate memory for -maxsigcachesize: '%s' MiB</source>
        <translation type="unfinished">Không có khả năng để phân bổ bộ nhớ cho -maxsigcachesize: '%s' MiB</translation>
    </message>
    <message>
        <source>Unable to find UTXO for external input</source>
        <translation type="unfinished">Không thể tìm UTXO cho đầu vào từ bên ngoài</translation>
    </message>
    <message>
        <source>Unable to parse -maxuploadtarget: '%s'</source>
        <translation type="unfinished">Không thể parse -maxuploadtarget '%s</translation>
    </message>
    <message>
        <source>Unable to unload the wallet before migrating</source>
        <translation type="unfinished">Không thể gỡ ví trước khi chuyển</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Không thể đọc tệp cài đặt</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">Không thể ghi tệp cài đặt</translation>
    </message>
</context>
</TS>